#
# spec file for package ntfs2btrfs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ntfs2btrfs
Version:        20240115
Release:        2.1
Summary:        In-place conversion tool from NTFS to BTRFS
License:        GPL-2.0-only
URL:            https://github.com/maharmstone/ntfs2btrfs
Source:         https://github.com/maharmstone/ntfs2btrfs/archive/refs/tags/%{version}.tar.gz
Patch1:         0001-ntfs.h-include-memory.patch
BuildRequires:  cmake
BuildRequires:  fmt-devel
BuildRequires:  gcc-c++
BuildRequires:  libzstd-devel
BuildRequires:  lzo-devel
BuildRequires:  zlib-devel

%description
Ntfs2btrfs is a tool which does in-place conversion of Microsoft's NTFS
filesystem to the open-source filesystem Btrfs, much as btrfs-convert does for
ext2. The original image is saved as a reflink copy at image/ntfs.img, and if
you want to keep the conversion you can delete this to free up space.

%prep
%setup -q
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%license LICENCE
%doc README.md
%{_sbindir}/ntfs2btrfs
%{_mandir}/man8/ntfs2btrfs.8%{?ext_man}

%changelog
* Fri Nov  8 2024 dsterba@suse.cz
- fix build problems
- Added patch: 0001-ntfs.h-include-memory.patch
* Wed May  8 2024 dsterba@suse.cz
- update to version 20240115:
  - fix build with gcc 14
  - spec: use tag as version
* Mon Oct 23 2023 dsterba@suse.cz
- Update to version 20230501:
  * Fixed inline extent items being written out of order (not diagnosed by
    btrfs check)
  * Fixed metadata items being written with wrong level value (not diagnosed by
    btrfs check)
  * ADSes with overly-long names now get skipped
* Tue Nov 29 2022 Emily Roberts <nopeinomicon@posteo.net>
- Updated to version 20220812, changes from upstream are as follows:
  * Added --no-datasum option, to skip calculating checksums
  * LXSS / WSL metadata is now preserved
  * Fixed lowercase drive letters not being recognized
  * Fixed crash due to iterator invalidation (thanks to nyanpasu64)
  * Fixed corruption when NTFS places file in last megabyte of disk
* Tue Nov 16 2021 dsterba@suse.cz
- 20210923
  * Added (Btrfs) compression support (zlib, lzo, and zstd)
  * Added support for other hash algorithms: xxhash, sha256, and blake2
  * Added support for rolling back to NTFS
  * Added support for NT4-style security descriptors
  * Increased conversion speed for volume with many inodes
  * Fixed bug when fragmented file was in superblock location
  * Fixed buffer overflow when reading security descriptors
  * Fixed bug where filesystems would be corrupted in a way that btrfs check doesn't pick up
- 20210523
  * Improved handling of large compressed files
- 20210402 (source code only release)
  * Fixes for compilation on non-amd64 architectures
- 20210105
  * Added support for NTFS compression
  * Added support for "WOF compressed data"
  * Fixed problems caused by sparse files
  * Miscellaneous bug fixes
- 20201108
  * Improved error handling
  * Added better message if NTFS is corrupted or unclean
  * Better handling of relocations
- 20200330
  * Initial release
